@@ -1,7 +1,6 @@
 import numpy as np
 from xml.etree import ElementTree as ET
 from collections import OrderedDict
-from pprint import pprint
 
 from pykin.urdf.urdf_tree import URDFTree
 from pykin.geometry.frame import Joint, Link, Frame
@@ -10,6 +9,7 @@ from pykin.kinematics.transform import Transform
 JOINT_TYPE_MAP = {'revolute': 'revolute',
                   'fixed': 'fixed',
                   'prismatic': 'prismatic'}
+
 LINK_TYPE_MAP = { 'cylinder' : 'cylinder',
                   'sphere'   : 'sphere',
                   'box'      : 'box',
@@ -61,7 +61,7 @@ class URDFParser:
         attrib = link_tag.attrib
         link_name = attrib.get('name', 'link_' + str(idx))
         frame = Frame(link_name + '_frame',
-                      link=Link(link_name, offset=Transform(), dtype=None, radius=0, length=0, size=np.zeros(3)))
+                      link=Link(link_name, offset=Transform(), dtype=None, radius=0, length=0, size=np.zeros(3), color={}))
 
         # dtype, length, radius
         for collision_tag in link_tag.findall('collision'):
@@ -73,8 +73,6 @@ class URDFParser:
             for geometry_tag in collision_tag.findall('geometry'):
                 for shape_type in ["cylinder", "sphere", "mesh"]:
                     for shapes in geometry_tag.findall(shape_type):
-                        if "visual" in link_name:
-                            continue 
                         frame.link.dtype = shapes.tag
                         frame.link.length = shapes.attrib.get('length', 0)
                         frame.link.radius = shapes.attrib.get('radius', 0)
@@ -89,8 +87,9 @@ class URDFParser:
                         frame.link.mesh = shapes.attrib.get('filename', None)
 
             for material_tag in visual_tag.findall('material'):
-                frame.link.color = material_tag.get('name')
-        
+                for colors in material_tag.findall('color'):
+                    frame.link.color[material_tag.get('name')] = _convert_string_to_narray(
+                        colors.attrib.get('rgba'))
         return frame
 
     def _parse_joint(self, joint_tag, idx):
@@ -142,10 +141,11 @@ class URDFParser:
                 chil_link = links[joint.child]
                 child_frame.link = Link(chil_link.name, 
                                         offset=_convert_transform(chil_link.offset),
-                                        dtype=LINK_TYPE_MAP.get(
-                                            chil_link.dtype),
+                                        dtype=LINK_TYPE_MAP.get(chil_link.dtype),
                                         radius=chil_link.radius,
-                                        length=chil_link.length)
+                                        length=chil_link.length,
+                                        size=chil_link.size,
+                                        color=chil_link.color)
 
                 child_frame.children = self._build_chain_recursive(child_frame.link, links, joints)
                 children.append(child_frame)
